==> Paws-0.31.tar.gz: Paws-0.31/lib/Paws/CodeDeploy/GetOnPremisesInstance.pm <==

package Paws::CodeDeploy::GetOnPremisesInstance;
  use Moose;
  has InstanceName => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'instanceName' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetOnPremisesInstance');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodeDeploy::GetOnPremisesInstanceOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::GetOnPremisesInstance - Arguments for method GetOnPremisesInstance on Paws::CodeDeploy

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetOnPremisesInstance on the 
AWS CodeDeploy service. Use the attributes of this class
as arguments to method GetOnPremisesInstance.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetOnPremisesInstance.

As an example:

  $service_obj->GetOnPremisesInstance(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> InstanceName => Str

The name of the on-premises instance about which to get information.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetOnPremisesInstance in L<Paws::CodeDeploy>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/CodeDeploy/GetOnPremisesInstance.pm <==

package Paws::CodeDeploy::GetOnPremisesInstance;
  use Moose;
  has InstanceName => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'instanceName' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetOnPremisesInstance');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodeDeploy::GetOnPremisesInstanceOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::GetOnPremisesInstance - Arguments for method GetOnPremisesInstance on L<Paws::CodeDeploy>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetOnPremisesInstance on the
L<AWS CodeDeploy|Paws::CodeDeploy> service. Use the attributes of this class
as arguments to method GetOnPremisesInstance.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetOnPremisesInstance.

=head1 SYNOPSIS

    my $codedeploy = Paws->service('CodeDeploy');
    my $GetOnPremisesInstanceOutput = $codedeploy->GetOnPremisesInstance(
      InstanceName => 'MyInstanceName',

    );

    # Results:
    my $InstanceInfo = $GetOnPremisesInstanceOutput->InstanceInfo;

    # Returns a L<Paws::CodeDeploy::GetOnPremisesInstanceOutput> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/codedeploy/GetOnPremisesInstance>

=head1 ATTRIBUTES


=head2 B<REQUIRED> InstanceName => Str

The name of the on-premises instance about which to get information.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetOnPremisesInstance in L<Paws::CodeDeploy>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
